#ifndef FILE_H
#define FILE_H

/*  gtail
 *  Copyright (C) 1999 Didier Remy
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

/*
 * $Log: file.h,v $
 * Revision 1.5  1999/12/21 18:22:32  didier
 * Gestion du PIDs pour les commandes
 * Gestion d'tat "mort" pour les commandes termines
 *
 * Revision 1.4  1999/11/20 15:44:00  didier
 * Ajout du type bool
 *
 * Ajout du nom du fichier dans la structure xfileinfo
 *
 * Ajout de ma fonction (xt)basename, celle de Linux/Debian n'est pas documente
 *
 * Revision 1.3  1999/11/10 20:32:33  didier
 * Changement cosmtique
 *
 */

#include <sys/types.h> /* pid_t */


#ifndef FALSE
typedef enum {FALSE, TRUE} bool_t;
#else
typedef int bool_t;
#endif

/* cration de descripteur de XFIBLOCKSIZE en XFIBLOCKSIZE */
#define XFIBLOCKSIZE 16

/*
 * IS_DEAD : la commande espionne est termin et l'utilisateur a vu les modif.
 * IS_DEADNCHANGED : la commande espionne est termin et pas vu modif.
 * NOT_CHANGED : le fichier est ouvert et n'est pas modifi depuis la dernire
 *               lecture de l'utilisateur (une toile suit le nom de fichier
 *               dans le notebook jusqu' ce qu'on click dessus
 * CHANGED : le fichier est ouvert et l'utilisateur n'a pas encore vu les modif
 * UNUSED : cet enregistrement est inutilis pour le moment
 * LAST : cet enregistrement est le dernier lment allou de la structure
 */
typedef enum { IS_DEAD, IS_DEADNCHANGED,
	       NOT_CHANGED, CHANGED,
	       UNUSED, LAST } xfi_status;

/* La structure qui contient les info sur le fichier/commande  lire, son
 * status, le widget ou le dessiner, le nom du fichier et un entier qui dit si
 * plusieurs tab_label vont avoir le mme nom */
typedef struct {
  int fd;                 /* le file descriptor ouvert par open() / -1 sinon */
  pid_t pid;              /* si c'est une commande */

  unsigned int repeat_time; /* nombre de seconde avant de relancer la cmd */
  /*unsigned int elapse_time; /* nombre de seconde dj coules */
  int timer;

  xfi_status has_changed; /* etat d'utilisation de cette structure */

  void * w;               /* le widget Text (GtkText*) affichant ce fichier */

  char * filename;        /* le nom complet (avec chemin d'accs) du fichier */
  int idem;               /* si plusieurs nom identique */

  int last_new_line;      /*l'indice dans le texte dj affich du dernier \n*/
} xfileinfo;

extern xfileinfo *xfi;

/* init de xfi, automatiquement appel par le premier add_file */
/* FALSE = out of mem */
bool_t init_fi();

/* ajoute un fichier dans xfi, alloue en plus si ncessaire
 * donne l'indice dans xfi ou l'enregistrement est cre
 */
int add_stream(char *filename, int, void *);
int add_file(const char *);
int add_pipe(const char *, pid_t *);

/* supprime un fichier de la liste */
void remove_file(int);

void xfi_free(void);

char *dirname(char *);
char *xtbasename(const char *);

#endif
